// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qmessagelogger_wrapper.h"

// Argument includes
#include <qloggingcategory.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMessageLogger_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QMessageLogger >()))
        return -1;

    ::QMessageLogger *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1 || numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    if (PyArg_UnpackTuple(args, "QMessageLogger", 0, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QMessageLogger::QMessageLogger()
    // 1: QMessageLogger::QMessageLogger(const char*,int,const char*)
    // 2: QMessageLogger::QMessageLogger(const char*,int,const char*,const char*)
    if (numArgs == 0) {
        overloadId = 0; // QMessageLogger()
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // QMessageLogger(const char*,int,const char*)
        } else if (numArgs == 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
            overloadId = 2; // QMessageLogger(const char*,int,const char*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QMessageLogger()
        {

            // QMessageLogger()
            cptr = new ::QMessageLogger();
            break;
        }
        case 1: // QMessageLogger(const char *file, int line, const char *function)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMessageLogger(const char*,int,const char*)
                cptr = new ::QMessageLogger(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // QMessageLogger(const char *file, int line, const char *function, const char *category)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QMessageLogger(const char*,int,const char*,const char*)
                cptr = new ::QMessageLogger(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QMessageLogger >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QMessageLoggerFunc_critical(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "critical", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMessageLogger::critical(QLoggingCategory,const char*)const
    // 1: QMessageLogger::critical(const char*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 1; // critical(const char*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // critical(QLoggingCategory,const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "critical", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // critical(const QLoggingCategory &cat, const char *msg) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLoggingCategory *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // critical(QLoggingCategory,const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->critical((*cppArg0), "%s", cppArg1); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // critical(const char *msg) const
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // critical(const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->critical("%s", cppArg0); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMessageLoggerFunc_debug(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "debug", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMessageLogger::debug(QLoggingCategory,const char*)const
    // 1: QMessageLogger::debug(const char*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 1; // debug(const char*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // debug(QLoggingCategory,const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "debug", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // debug(const QLoggingCategory &cat, const char *msg) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLoggingCategory *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // debug(QLoggingCategory,const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->debug((*cppArg0), "%s", cppArg1); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // debug(const char *msg) const
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // debug(const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->debug("%s", cppArg0); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMessageLoggerFunc_fatal(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fatal", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMessageLogger::fatal(QLoggingCategory,const char*)const
    // 1: QMessageLogger::fatal(const char*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 1; // fatal(const char*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // fatal(QLoggingCategory,const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fatal", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fatal(const QLoggingCategory &cat, const char *msg) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLoggingCategory *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fatal(QLoggingCategory,const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->fatal((*cppArg0), "%s", cppArg1); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // fatal(const char *msg) const
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fatal(const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->fatal("%s", cppArg0); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMessageLoggerFunc_info(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "info", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMessageLogger::info(QLoggingCategory,const char*)const
    // 1: QMessageLogger::info(const char*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 1; // info(const char*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // info(QLoggingCategory,const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "info", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // info(const QLoggingCategory &cat, const char *msg) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLoggingCategory *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // info(QLoggingCategory,const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->info((*cppArg0), "%s", cppArg1); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // info(const char *msg) const
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // info(const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->info("%s", cppArg0); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMessageLoggerFunc_noDebug(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QMessageLogger::noDebug(const char*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArg)))) {
        overloadId = 0; // noDebug(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "noDebug", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // noDebug(const char*)const
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
            Py_BEGIN_ALLOW_THREADS
            cppSelf->noDebug("%s", cppArg0); // Uses placeholder for security reasons
            Py_END_ALLOW_THREADS
            // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
            // ========================================================================
            // End of code injection

        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_QMessageLoggerFunc_warning(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QMessageLogger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "warning", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QMessageLogger::warning(QLoggingCategory,const char*)const
    // 1: QMessageLogger::warning(const char*)const
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 1; // warning(const char*)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLoggingCategory_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // warning(QLoggingCategory,const char*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "warning", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // warning(const QLoggingCategory &cat, const char *msg) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLoggingCategory *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // warning(QLoggingCategory,const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->warning((*cppArg0), "%s", cppArg1); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-logcategory-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // warning(const char *msg) const
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // warning(const char*)const
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                Py_BEGIN_ALLOW_THREADS
                cppSelf->warning("%s", cppArg0); // Uses placeholder for security reasons
                Py_END_ALLOW_THREADS
                // END of custom code block [file: ../glue/qtcore.cpp (qmessagelogger-format-string)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_QMessageLogger_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QMessageLogger_methods[] = {
    {"critical", reinterpret_cast<PyCFunction>(Sbk_QMessageLoggerFunc_critical), METH_VARARGS, nullptr},
    {"debug", reinterpret_cast<PyCFunction>(Sbk_QMessageLoggerFunc_debug), METH_VARARGS, nullptr},
    {"fatal", reinterpret_cast<PyCFunction>(Sbk_QMessageLoggerFunc_fatal), METH_VARARGS, nullptr},
    {"info", reinterpret_cast<PyCFunction>(Sbk_QMessageLoggerFunc_info), METH_VARARGS, nullptr},
    {"noDebug", reinterpret_cast<PyCFunction>(Sbk_QMessageLoggerFunc_noDebug), METH_O, nullptr},
    {"warning", reinterpret_cast<PyCFunction>(Sbk_QMessageLoggerFunc_warning), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QMessageLogger_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QMessageLogger_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QMessageLogger_Type = nullptr;
static PyTypeObject *Sbk_QMessageLogger_TypeF(void)
{
    return _Sbk_QMessageLogger_Type;
}

static PyType_Slot Sbk_QMessageLogger_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QMessageLogger_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QMessageLogger_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QMessageLogger_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QMessageLogger_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QMessageLogger_spec = {
    "2:PySide6.QtCore.QMessageLogger",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QMessageLogger_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QMessageLogger_PythonToCpp_QMessageLogger_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QMessageLogger_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QMessageLogger_PythonToCpp_QMessageLogger_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QMessageLogger_TypeF()))
        return QMessageLogger_PythonToCpp_QMessageLogger_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QMessageLogger_PTR_CppToPython_QMessageLogger(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QMessageLogger_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QMessageLogger_SignatureStrings[] = {
    "2:PySide6.QtCore.QMessageLogger(self)",
    "1:PySide6.QtCore.QMessageLogger(self,file:char*,line:int,function:char*)",
    "0:PySide6.QtCore.QMessageLogger(self,file:char*,line:int,function:char*,category:char*)",
    "1:PySide6.QtCore.QMessageLogger.critical(self,cat:PySide6.QtCore.QLoggingCategory,msg:str)",
    "0:PySide6.QtCore.QMessageLogger.critical(self,msg:str)",
    "1:PySide6.QtCore.QMessageLogger.debug(self,cat:PySide6.QtCore.QLoggingCategory,msg:str)",
    "0:PySide6.QtCore.QMessageLogger.debug(self,msg:str)",
    "1:PySide6.QtCore.QMessageLogger.fatal(self,cat:PySide6.QtCore.QLoggingCategory,msg:str)",
    "0:PySide6.QtCore.QMessageLogger.fatal(self,msg:str)",
    "1:PySide6.QtCore.QMessageLogger.info(self,cat:PySide6.QtCore.QLoggingCategory,msg:str)",
    "0:PySide6.QtCore.QMessageLogger.info(self,msg:str)",
    "PySide6.QtCore.QMessageLogger.noDebug(self,arg__1:str)",
    "1:PySide6.QtCore.QMessageLogger.warning(self,cat:PySide6.QtCore.QLoggingCategory,msg:str)",
    "0:PySide6.QtCore.QMessageLogger.warning(self,msg:str)",
    nullptr}; // Sentinel
#else
static constexpr size_t QMessageLogger_SignatureByteSize = 192;
static constexpr uint8_t QMessageLogger_SignatureBytes[192] = {
    0x78, 0xda, 0xb5, 0x90, 0x41, 0x0a, 0xc2, 0x30, 0x10, 0x45, 0xf7, 0x9e, 0xc4, 0x4a, 0x28, 0xd6,
    0x85, 0x8b, 0x6c, 0xeb, 0x52, 0xc1, 0xe2, 0x01, 0x4a, 0x4c, 0x27, 0x71, 0x20, 0x26, 0x30, 0x49,
    0x91, 0xde, 0xde, 0x4a, 0xb5, 0xad, 0x0a, 0x36, 0x0b, 0xbb, 0x1d, 0xfe, 0x7f, 0xf3, 0x66, 0x36,
    0xfc, 0xd8, 0x9c, 0xb0, 0x82, 0x6d, 0x5a, 0x84, 0xdc, 0x11, 0xa4, 0xc5, 0x01, 0xbc, 0x17, 0x1a,
    0xf6, 0x4e, 0x6b, 0xa0, 0xa5, 0x07, 0xa3, 0x92, 0x45, 0x16, 0x91, 0x62, 0x0a, 0x0d, 0x70, 0x79,
    0x11, 0xb4, 0x62, 0x06, 0x2d, 0x70, 0xb4, 0x81, 0xa9, 0xda, 0xca, 0x80, 0xce, 0x76, 0xf3, 0x64,
    0xb1, 0xfe, 0x0f, 0x88, 0x49, 0x11, 0x40, 0x3b, 0x6a, 0x5e, 0xdc, 0x09, 0xc1, 0x54, 0x12, 0x06,
    0x94, 0xc2, 0x74, 0x0b, 0xda, 0xf6, 0x57, 0xfe, 0x11, 0x44, 0xab, 0xf3, 0x27, 0x98, 0x5d, 0xbd,
    0xe6, 0x3e, 0xd0, 0xa4, 0xf2, 0x07, 0xba, 0xaf, 0x4d, 0x19, 0x55, 0x70, 0xae, 0xf5, 0x0c, 0x3a,
    0x23, 0x6e, 0xb4, 0x8b, 0x12, 0x61, 0x96, 0xd7, 0x8c, 0xb8, 0xd1, 0x2e, 0x68, 0x95, 0x9b, 0x41,
    0x65, 0xc0, 0xf6, 0x95, 0xdf, 0x05, 0xeb, 0x76, 0xc3, 0x27, 0x05, 0xe9, 0xb2, 0xcc, 0xe2, 0x0e,
    0xb8, 0x09, 0xb2, 0xad, 0xe2, 0x0c, 0x37, 0xbc, 0x91, 0xfb, 0xd6, 0x1d, 0x84, 0xc5, 0x56, 0x3e
};
#endif

PyTypeObject *init_QMessageLogger(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX].type;

    Shiboken::AutoDecRef Sbk_QMessageLogger_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QMessageLogger_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QMessageLogger",
        "QMessageLogger*",
        &Sbk_QMessageLogger_spec,
        &Shiboken::callCppDestructor< ::QMessageLogger >,
        Sbk_QMessageLogger_Type_bases.object(),
        0);
    auto *pyType = Sbk_QMessageLogger_TypeF(); // references _Sbk_QMessageLogger_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QMessageLogger_SignatureStrings);
#else
    InitSignatureBytes(pyType, QMessageLogger_SignatureBytes, QMessageLogger_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QMessageLogger_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QMessageLogger_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QMessageLogger_PythonToCpp_QMessageLogger_PTR,
        is_QMessageLogger_PythonToCpp_QMessageLogger_PTR_Convertible,
        QMessageLogger_PTR_CppToPython_QMessageLogger);

    Shiboken::Conversions::registerConverterName(converter, "QMessageLogger");
    Shiboken::Conversions::registerConverterName(converter, "QMessageLogger*");
    Shiboken::Conversions::registerConverterName(converter, "QMessageLogger&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QMessageLogger).name());

    qRegisterMetaType< ::QMessageLogger *>();

    return pyType;
}
