// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwebenginecore_python.h"

// main header
#include "qwebengineloadinginfo_wrapper.h"

// Argument includes
#include <QMultiMap>
#include <QString>
#include <QtWebEngineCore/qwebengineloadinginfo.h>
#include <qbytearray.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebEngineLoadingInfo_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QWebEngineLoadingInfo >()))
        return -1;

    ::QWebEngineLoadingInfo *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QWebEngineLoadingInfo", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QWebEngineLoadingInfo::QWebEngineLoadingInfo()
    // 1: QWebEngineLoadingInfo::QWebEngineLoadingInfo(QWebEngineLoadingInfo)
    if (numArgs == 0) {
        overloadId = 0; // QWebEngineLoadingInfo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QWebEngineLoadingInfo(QWebEngineLoadingInfo)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QWebEngineLoadingInfo()
        {

            // QWebEngineLoadingInfo()
            cptr = new ::QWebEngineLoadingInfo();
            break;
        }
        case 1: // QWebEngineLoadingInfo(const QWebEngineLoadingInfo &other)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWebEngineLoadingInfo cppArg0_local;
            ::QWebEngineLoadingInfo *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QWebEngineLoadingInfo(QWebEngineLoadingInfo)
                cptr = new ::QWebEngineLoadingInfo(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QWebEngineLoadingInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_errorCode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorCode()const
        int cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->errorCode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_errorDomain(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorDomain()const
        QWebEngineLoadingInfo::ErrorDomain cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->errorDomain();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // errorString()const
        QString cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->errorString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_isDownload(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDownload()const
        bool cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->isDownload();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_isErrorPage(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isErrorPage()const
        bool cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->isErrorPage();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_responseHeaders(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // responseHeaders()const
        QMultiMap<QByteArray,QByteArray> cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->responseHeaders();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWebEngineCoreTypeConverters[SBK_QtWebEngineCore_QMultiMap_QByteArray_QByteArray_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // status()const
        QWebEngineLoadingInfo::LoadStatus cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX])))->converter, &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfoFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // url()const
        QUrl cppResult = const_cast<const ::QWebEngineLoadingInfo *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_QWebEngineLoadingInfo__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QWebEngineLoadingInfo_PropertyStrings[] = {
    "errorCode:",
    "errorDomain:",
    "errorString:",
    "isDownload:",
    "isErrorPage:",
    "responseHeaders:",
    "status:",
    "url:",
    nullptr // Sentinel
};

static const char *Sbk_QWebEngineLoadingInfo_EnumFlagInfo[] = {
    "ErrorDomain:Enum",
    "LoadStatus:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QWebEngineLoadingInfo_methods[] = {
    {"errorCode", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_errorCode), METH_NOARGS, nullptr},
    {"errorDomain", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_errorDomain), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_errorString), METH_NOARGS, nullptr},
    {"isDownload", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_isDownload), METH_NOARGS, nullptr},
    {"isErrorPage", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_isErrorPage), METH_NOARGS, nullptr},
    {"responseHeaders", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_responseHeaders), METH_NOARGS, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_status), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfoFunc_url), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QWebEngineLoadingInfo__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QWebEngineLoadingInfo_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QWebEngineLoadingInfo_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QWebEngineLoadingInfo_Type = nullptr;
static PyTypeObject *Sbk_QWebEngineLoadingInfo_TypeF(void)
{
    return _Sbk_QWebEngineLoadingInfo_Type;
}

static PyType_Slot Sbk_QWebEngineLoadingInfo_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QWebEngineLoadingInfo_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QWebEngineLoadingInfo_spec = {
    "2:PySide6.QtWebEngineCore.QWebEngineLoadingInfo",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QWebEngineLoadingInfo_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QWebEngineLoadingInfo_LoadStatus(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineLoadingInfo::LoadStatus>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineLoadingInfo::LoadStatus *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineLoadingInfo_LoadStatus_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX])))
        return Enum_PythonToCpp_QWebEngineLoadingInfo_LoadStatus;
    return {};
}

static PyObject *QWebEngineLoadingInfo_LoadStatus_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineLoadingInfo::LoadStatus>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineLoadingInfo::LoadStatus *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QWebEngineLoadingInfo::ErrorDomain>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QWebEngineLoadingInfo::ErrorDomain *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX])))
        return Enum_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain;
    return {};
}

static PyObject *QWebEngineLoadingInfo_ErrorDomain_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QWebEngineLoadingInfo::ErrorDomain>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QWebEngineLoadingInfo::ErrorDomain *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QWebEngineLoadingInfo_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineLoadingInfo_TypeF()))
        return QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QWebEngineLoadingInfo_PTR_CppToPython_QWebEngineLoadingInfo(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QWebEngineLoadingInfo_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QWebEngineLoadingInfo_COPY_CppToPython_QWebEngineLoadingInfo(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QWebEngineLoadingInfo *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QWebEngineLoadingInfo_TypeF(), new ::QWebEngineLoadingInfo(*source), true, true);
}

// Python to C++ copy conversion.
static void QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QWebEngineLoadingInfo *>(cppOut) = *reinterpret_cast< ::QWebEngineLoadingInfo *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QWebEngineLoadingInfo_TypeF()))
        return QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QWebEngineLoadingInfo_SignatureStrings[] = {
    "1:PySide6.QtWebEngineCore.QWebEngineLoadingInfo(self,*:KeywordOnly=None,url:QUrl=None,isErrorPage:bool=None,status:QWebEngineLoadingInfo.LoadStatus=None,errorString:QString=None,errorDomain:QWebEngineLoadingInfo.ErrorDomain=None,errorCode:int=None,responseHeaders:QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]=None,isDownload:bool=None)",
    "0:PySide6.QtWebEngineCore.QWebEngineLoadingInfo(self,other:PySide6.QtWebEngineCore.QWebEngineLoadingInfo,*:KeywordOnly=None,url:QUrl=None,isErrorPage:bool=None,status:QWebEngineLoadingInfo.LoadStatus=None,errorString:QString=None,errorDomain:QWebEngineLoadingInfo.ErrorDomain=None,errorCode:int=None,responseHeaders:QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]=None,isDownload:bool=None)",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorCode(self)->int",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorDomain(self)->PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.errorString(self)->QString",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.isDownload(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.isErrorPage(self)->bool",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.responseHeaders(self)->QMultiMap[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.status(self)->PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.url(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWebEngineCore.QWebEngineLoadingInfo.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QWebEngineLoadingInfo_SignatureByteSize = 312;
static constexpr uint8_t QWebEngineLoadingInfo_SignatureBytes[312] = {
    0x78, 0xda, 0xed, 0x93, 0x4d, 0x4f, 0xc3, 0x30, 0x0c, 0x86, 0xef, 0xfb, 0x15, 0x1c, 0x19, 0x2a,
    0x15, 0x5c, 0x38, 0x44, 0x02, 0x09, 0xb6, 0x4a, 0x20, 0x18, 0xac, 0xaa, 0x10, 0x87, 0x09, 0x55,
    0x19, 0xf5, 0x4a, 0xa4, 0x10, 0x57, 0x4e, 0xaa, 0x29, 0xff, 0x9e, 0x74, 0x59, 0x3f, 0x04, 0xec,
    0x90, 0xee, 0xca, 0xa9, 0x4d, 0xec, 0x3c, 0xb6, 0x5f, 0xdb, 0x97, 0x6c, 0x69, 0x33, 0x51, 0xc0,
    0x55, 0x9c, 0x9a, 0x37, 0x58, 0x27, 0xaa, 0x14, 0x0a, 0x66, 0x48, 0x10, 0xa7, 0xdd, 0xf1, 0x09,
    0x79, 0x21, 0x54, 0xf9, 0xa0, 0x36, 0x78, 0xaa, 0x41, 0x6e, 0xa2, 0x33, 0xf6, 0x08, 0x76, 0x8b,
    0x54, 0xbc, 0x28, 0x69, 0xaf, 0x9f, 0x51, 0x41, 0x54, 0x93, 0x64, 0xe9, 0x2b, 0x49, 0x7f, 0x12,
    0x3a, 0x21, 0x42, 0x5a, 0xf2, 0x12, 0xd8, 0x1a, 0x71, 0x7f, 0xab, 0x0d, 0x37, 0xb5, 0x66, 0x7f,
    0x82, 0xe3, 0xe6, 0x3f, 0xdb, 0x39, 0x78, 0x67, 0x68, 0x00, 0x99, 0x21, 0x67, 0x67, 0xa9, 0xff,
    0x0e, 0x0c, 0x73, 0xfc, 0xe2, 0x42, 0x1d, 0x40, 0x25, 0xbd, 0xc7, 0xe0, 0xc9, 0x0c, 0x0b, 0x60,
    0x42, 0x19, 0x7f, 0x45, 0xa0, 0x2b, 0x54, 0x1a, 0xee, 0x81, 0x17, 0x40, 0x2e, 0xa9, 0x45, 0x2d,
    0x8d, 0x58, 0xf0, 0x6a, 0xd5, 0xeb, 0xe1, 0x65, 0xb8, 0xb3, 0x06, 0x6e, 0x89, 0xb8, 0x8d, 0x4e,
    0x0e, 0x9a, 0xde, 0xdb, 0xb2, 0xe7, 0xb8, 0x55, 0xd2, 0xa5, 0xd2, 0x57, 0x3d, 0x9d, 0x5c, 0x8c,
    0x91, 0x18, 0xcd, 0x27, 0x50, 0xd8, 0xc3, 0xff, 0xb6, 0x04, 0xb5, 0x25, 0x48, 0xdb, 0xb8, 0xcb,
    0x75, 0xd7, 0x9e, 0xe9, 0xf9, 0x8d, 0x4b, 0x79, 0x0c, 0xc2, 0xd7, 0xdf, 0x42, 0xc2, 0x00, 0x03,
    0x01, 0xc7, 0x84, 0xf6, 0xdd, 0x6a, 0x43, 0xef, 0x9b, 0x17, 0x08, 0xea, 0xa5, 0x6c, 0x39, 0x8d,
    0xa2, 0xc1, 0x90, 0x6e, 0x0c, 0x8f, 0xa0, 0xfc, 0x18, 0x95, 0xae, 0xae, 0xe3, 0x26, 0x26, 0x30,
    0x09, 0xbf, 0x3b, 0xe3, 0xda, 0xd9, 0xaf, 0x56, 0x60, 0x50, 0xb7, 0xd4, 0xbf, 0x23, 0x7a, 0x7f,
    0xb7, 0xea, 0x81, 0xb0, 0x3c, 0xff, 0xc0, 0xca, 0xe6, 0x79, 0x4b, 0x34, 0xb6, 0x72, 0xa6, 0x38,
    0x73, 0xa7, 0xc9, 0x37, 0x1a, 0x23, 0x3d, 0xca
};
#endif

PyTypeObject *init_QWebEngineLoadingInfo(PyObject *module)
{
    if (SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX].type != nullptr)
        return SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX].type;

    Shiboken::AutoDecRef Sbk_QWebEngineLoadingInfo_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QWebEngineLoadingInfo_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QWebEngineLoadingInfo",
        "QWebEngineLoadingInfo",
        &Sbk_QWebEngineLoadingInfo_spec,
        &Shiboken::callCppDestructor< ::QWebEngineLoadingInfo >,
        Sbk_QWebEngineLoadingInfo_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QWebEngineLoadingInfo_TypeF(); // references _Sbk_QWebEngineLoadingInfo_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QWebEngineLoadingInfo_SignatureStrings);
#else
    InitSignatureBytes(pyType, QWebEngineLoadingInfo_SignatureBytes, QWebEngineLoadingInfo_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QWebEngineLoadingInfo_PropertyStrings);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR,
        is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_PTR_Convertible,
        QWebEngineLoadingInfo_PTR_CppToPython_QWebEngineLoadingInfo,
        QWebEngineLoadingInfo_COPY_CppToPython_QWebEngineLoadingInfo);

    Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo*");
    Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QWebEngineLoadingInfo).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY,
        is_QWebEngineLoadingInfo_PythonToCpp_QWebEngineLoadingInfo_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QWebEngineLoadingInfo_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LoadStatus'.
    const char *LoadStatus_Initializer[] = {
        "LoadStartedStatus",
        "LoadStoppedStatus",
        "LoadSucceededStatus",
        "LoadFailedStatus",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LoadStatus_InitializerValues[] = {
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadStartedStatus),   //  0x00  0
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadStoppedStatus),   //  0x01  1
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadSucceededStatus), //  0x02  2
        uint8_t(QWebEngineLoadingInfo::LoadStatus::LoadFailedStatus)     //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineLoadingInfo_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus",
        LoadStatus_Initializer, LoadStatus_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_LoadStatus_IDX].type = EType;
    // Register converter for enum 'QWebEngineLoadingInfo::LoadStatus'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineLoadingInfo_LoadStatus_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineLoadingInfo_LoadStatus,
            is_Enum_PythonToCpp_QWebEngineLoadingInfo_LoadStatus_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo::LoadStatus");
        Shiboken::Conversions::registerConverterAlias(converter, "LoadStatus");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LoadStatus' enum.

    // Initialization of enum 'ErrorDomain'.
    const char *ErrorDomain_Initializer[] = {
        "NoErrorDomain",
        "InternalErrorDomain",
        "ConnectionErrorDomain",
        "CertificateErrorDomain",
        "HttpErrorDomain",
        "FtpErrorDomain",
        "DnsErrorDomain",
        "HttpStatusCodeDomain",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ErrorDomain_InitializerValues[] = {
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::NoErrorDomain),          //  0x00  0
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::InternalErrorDomain),    //  0x01  1
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::ConnectionErrorDomain),  //  0x02  2
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::CertificateErrorDomain), //  0x03  3
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::HttpErrorDomain),        //  0x04  4
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::FtpErrorDomain),         //  0x05  5
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::DnsErrorDomain),         //  0x06  6
        uint8_t(QWebEngineLoadingInfo::ErrorDomain::HttpStatusCodeDomain)    //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QWebEngineLoadingInfo_TypeF(),
        "2:PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain",
        ErrorDomain_Initializer, ErrorDomain_InitializerValues);
    SbkPySide6_QtWebEngineCoreTypeStructs[SBK_QWebEngineLoadingInfo_ErrorDomain_IDX].type = EType;
    // Register converter for enum 'QWebEngineLoadingInfo::ErrorDomain'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QWebEngineLoadingInfo_ErrorDomain_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain,
            is_Enum_PythonToCpp_QWebEngineLoadingInfo_ErrorDomain_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QWebEngineLoadingInfo::ErrorDomain");
        Shiboken::Conversions::registerConverterAlias(converter, "ErrorDomain");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ErrorDomain' enum.

    qRegisterMetaType< ::QWebEngineLoadingInfo >("QWebEngineLoadingInfo");
    qRegisterMetaType< ::QWebEngineLoadingInfo::LoadStatus >("QWebEngineLoadingInfo::LoadStatus");
    qRegisterMetaType< ::QWebEngineLoadingInfo::ErrorDomain >("QWebEngineLoadingInfo::ErrorDomain");

    return pyType;
}
